Module spaceapi_server::modifiers [−][src]
Modifiers which can be injected by the application logic to change the state dynamically per request.
Structs
This modifier updates the opening state based on the first people now present sensor (if present).
Traits
StatusModifiers are used to modify the status