Enum spaceapi_server::sensors::SensorError []

pub enum SensorError {
    UnknownSensor(String),
    Redis(RedisError),
    R2d2(GetTimeout),
}

A SensorError wraps problems that can occur when reading or updating sensor values.

This type is only used for internal purposes and should not be used by third party code.

Variants