Enum spaceapi_server::sensors::SensorError
[−]
pub enum SensorError {
UnknownSensor(String),
Redis(RedisError),
R2d2(GetTimeout),
}A SensorError wraps problems that can occur when reading or updating sensor values.
This type is only used for internal purposes and should not be used by third party code.
Variants
UnknownSensor(String)Redis(RedisError)R2d2(GetTimeout)Trait Implementations
impl Debug for SensorError[src]
impl From<String> for SensorError
fn from(value: String) -> SensorError
Performs the conversion.
impl From<RedisError> for SensorError
fn from(value: RedisError) -> SensorError
Performs the conversion.
impl From<GetTimeout> for SensorError
fn from(value: GetTimeout) -> SensorError
Performs the conversion.
impl Display for SensorError
fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter. Read more